Introduction
============

This package provides a Generic Setup extension profile that will
install an IntId utility in a CMF portal.  Additionally, it registers
intid handlers for the standard object events on CMF content.  Finally,
it finds existing CMF content in the portal and registers it with the
IntId utility.

Installation notes
------------------

Installation for Plone 3.3 requires plone.app.intid <= 1.0b3 and
five.intid <= 0.4.3.
